methods for class wle.aic or summary.wle.aic.summary.wle.aic(object, num.max=20, ...)print.wle.aic(x, digits = max(3, getOption("digits") - 3), ...)
print.summary.wle.aic(x, digits = max(3, getOption("digits") - 3), ...)
wle.aic.wle.aic or summary.wle.aic.summary.wle.aic returns a list:num.max best models with their Weighted Akaike Information Criterion.wle.aic a function for evaluate the Weighted Akaike Information Criterion in the linear models.