methods for class wle.cv or summary.wle.cv.summary.wle.cv(object, num.max=20, ...)print.wle.cv(x, digits = max(3, getOption("digits") - 3), ...)
print.summary.wle.cv(x, digits = max(3, getOption("digits") - 3), ...)
wle.cv.wle.cv or summary.wle.cv.summary.wle.cv returns a list:num.max best models with their estimated prediction error using WCV.wle.cv a function for evaluate the Weighted Cross Validation criterion in the linear models.