wle.normal.summaries: Summaries and methods for wle.normal
Description
Until now, only print methods is available for class wle.normal. print.wle.normal print nicely the output.Usage
print.wle.normal(x, digits = max(3, getOption("digits") - 3), ...)Arguments
x
an object of class wle.normal.
See Also
wle.normal a function for estimating normal location and scale models.