wle.onestep(formula, data=list(), model=TRUE, x=FALSE,
y=FALSE, ini.param, ini.scale, raf="HD",
smooth=0.0320018, num.step=1, contrasts=NULL)wle.stepwise is called from.TRUE the corresponding components of the fit (the model frame, the model matrix, the
response.)raf="HD": Hellinger Distance RAF,
raf="NED": Negative Exponential Disparity RAF,
raf="SCHI2": Symmetric Chi-Squared Disparity RAF.
contrasts.arg
of model.matrix.default.wle.onestep returns an object of class "wle.onestep".Only print method is implemented for this class.
The object returned by wle.onestep are:
model=TRUE a matrix with first column the dependent variable and the remain column the explanatory variables for the full model.x=TRUE a matrix with the explanatory variables for the full model.y=TRUE a vector with the dependent variable.Agostinelli, C., (1998). Inferenza statistica robusta basata sulla funzione di verosimiglianza pesata: alcuni sviluppi, Ph.D Thesis, Department of Statistics, University of Padova.
Agostinelli, C., Markatou, M., (1998). A one-step robust estimator for regression based on the weighted likelihood reweighting scheme, Statistics & Probability Letters, Vol. 37, n. 4, 341-350.
Agostinelli, C., (1998). Verosimiglianza pesata nel modello di regressione lineare, XXXIX Riunione scientifica della Societ`a Italiana di Statistica, Sorrento 1998.
library(wle)
library(lqs)
data(artificial)
result.lts <- lqs(y.artificial~x.artificial,
method = "lts")
result.wle <- wle.onestep(y.artificial~x.artificial,
ini.param=result.lts$coefficients,
ini.scale=result.lts$scale[1])
result.wleRun the code above in your browser using DataLab